summaryrefslogtreecommitdiffstats
path: root/kturtle
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commitd8762de95349dc6edaa34db9bf699b367c1af6b1 (patch)
tree8c76a6ab8e4e92d13196cb11ddab2d0fb64ec680 /kturtle
parent03458c4e2ca2e92deafe078d0e09e1acd4c4765f (diff)
downloadtdeedu-d8762de95349dc6edaa34db9bf699b367c1af6b1.tar.gz
tdeedu-d8762de95349dc6edaa34db9bf699b367c1af6b1.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kturtle')
-rw-r--r--kturtle/src/canvas.cpp12
-rw-r--r--kturtle/src/executer.cpp2
-rw-r--r--kturtle/src/kturtle.cpp14
-rw-r--r--kturtle/src/parser.cpp4
4 files changed, 16 insertions, 16 deletions
diff --git a/kturtle/src/executer.cpp b/kturtle/src/executer.cpp
index e71204b4..9f88cc40 100644
--- a/kturtle/src/executer.cpp
+++ b/kturtle/src/executer.cpp
@@ -329,7 +329,7 @@ void Executer::execForEach(TreeNode* node)
bBreak = false;
- int i = expStr2.tqcontains(expStr1, false);
+ int i = expStr2.contains(expStr1, false);
for ( ; i > 0; i-- )
{
if (bAbort) return;
diff --git a/kturtle/src/parser.cpp b/kturtle/src/parser.cpp
index 64d83cb0..1d8fc5c4 100644
--- a/kturtle/src/parser.cpp
+++ b/kturtle/src/parser.cpp
@@ -188,7 +188,7 @@ TreeNode* Parser::Factor()
case tokUnknown:
node = getId();
- if (learnedFunctionList.tqcontains(rememberedToken.look) > 0) // is function call
+ if (learnedFunctionList.contains(rememberedToken.look) > 0) // is function call
{
delete node;
node = FunctionCall(rememberedToken);
@@ -1057,7 +1057,7 @@ TreeNode* Parser::Other()
matchToken(tokUnknown);
if (currentToken.type == tokAssign) return Assignment(rememberedToken);
- else if (learnedFunctionList.tqcontains(rememberedToken.look) > 0)
+ else if (learnedFunctionList.contains(rememberedToken.look) > 0)
{
TreeNode* node;
node = FunctionCall(rememberedToken);
diff --git a/kturtle/src/canvas.cpp b/kturtle/src/canvas.cpp
index e21ad4ea..e0a4ed05 100644
--- a/kturtle/src/canvas.cpp
+++ b/kturtle/src/canvas.cpp
@@ -18,7 +18,7 @@
// Note on this file:
// It tqcontains 200 lines of code just to make sure very long line are drawn correctly
// till a certain extent... Beyond that extent the code just cuts the crap, since use user
// it then probably not doing anything usefull anymore; so he she will not notice the code
// is cheating a bit in order to prevent CPU hogging.
@@ -297,11 +297,11 @@ void Canvas::slotPrint(TQString text)
void Canvas::slotFontType(TQString family, TQString extra)
{
font.setFamily(family);
- font.setBold( extra.tqcontains("bold") > 0 );
- font.setItalic( extra.tqcontains("italic") > 0 );
- font.setUnderline( extra.tqcontains("underline") > 0 );
- font.setOverline( extra.tqcontains("overline") > 0 );
- font.setStrikeOut( extra.tqcontains("strikeout") > 0 );
+ font.setBold( extra.contains("bold") > 0 );
+ font.setItalic( extra.contains("italic") > 0 );
+ font.setUnderline( extra.contains("underline") > 0 );
+ font.setOverline( extra.contains("overline") > 0 );
+ font.setStrikeOut( extra.contains("strikeout") > 0 );
}
void Canvas::slotFontSize(int px)
@@ -18,7 +18,7 @@
// Note on this file:
-// It tqcontains 200 lines of code just to make sure very long line are drawn correctly
+// It contains 200 lines of code just to make sure very long line are drawn correctly
// till a certain extent... Beyond that extent the code just cuts the crap, since use user
// it then probably not doing anything usefull anymore; so he she will not notice the code
diff --git a/kturtle/src/kturtle.cpp b/kturtle/src/kturtle.cpp
index 49f47d11..ffa528f3 100644
--- a/kturtle/src/kturtle.cpp
+++ b/kturtle/src/kturtle.cpp
@@ -650,7 +650,7 @@ void MainWindow::slotMessageDialog(TQString text)
// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, tqfind, tqreplace, linenumbers etc.)
void MainWindow::slotEditor()
{
@@ -716,7 +716,7 @@ void MainWindow::slotClearSelection()
void MainWindow::slotFind()
{
- KAction *a = editor->actionCollection()->action("edit_tqfind");
+ KAction *a = editor->actionCollection()->action("edit_find");
a->activate();
}
@@ -734,7 +734,7 @@ void MainWindow::slotFindPrevious()
void MainWindow::slotReplace()
{
- KAction* a = editor->actionCollection()->action("edit_tqreplace");
+ KAction* a = editor->actionCollection()->action("edit_replace");
a->activate();
}
@@ -1071,7 +1071,7 @@ void MainWindow::slotContextHelpUpdate()
int start, length, pos;
pos = 0;
- if ( line.tqcontains('"') )
+ if ( line.contains('"') )
{
TQRegExp delimitedStrings("(\"[^\"\\\\\\r\\n]*(\\\\.[^\"\\\\\\r\\n]*)*\")");
while ( delimitedStrings.search(line, pos) != -1 )
@@ -1112,13 +1112,13 @@ void MainWindow::slotContextHelpUpdate()
else if ( !translate->name2key( cursorWord.lower() ).isEmpty() ) helpKeyword = cursorWord;
else if ( !translate->alias2key( cursorWord.lower() ).isEmpty() ) helpKeyword = cursorWord;
- else if ( cursorWord.tqfind( TQRegExp("[\\d.]+") ) == 0 ) helpKeyword = i18n("<number>");
+ else if ( cursorWord.find( TQRegExp("[\\d.]+") ) == 0 ) helpKeyword = i18n("<number>");
- else if ( cursorWord.tqfind( TQRegExp("[+\\-*/\\(\\)]") ) == 0 ) helpKeyword = i18n("<math>");
+ else if ( cursorWord.find( TQRegExp("[+\\-*/\\(\\)]") ) == 0 ) helpKeyword = i18n("<math>");
else if ( cursorWord == TQString("=") ) helpKeyword = i18n("<assignment>");
- else if ( cursorWord.tqfind( TQRegExp("==|<|>|<=|>=|!=") ) == 0 ) helpKeyword = i18n("<question>");
+ else if ( cursorWord.find( TQRegExp("==|<|>|<=|>=|!=") ) == 0 ) helpKeyword = i18n("<question>");
// if we come here we either have an ID of some sort or an error
// all we can do is try to catch some errors (TODO) and then...
@@ -650,7 +650,7 @@ void MainWindow::slotMessageDialog(TQString text)
-// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, tqfind, tqreplace, linenumbers etc.)
+// BEGIN editor connections (undo, redo, cut, copy, paste, cursor, selections, find, replace, linenumbers etc.)
void MainWindow::slotEditor()
{